# Foreign Key

## Field.foreign_key(name: str, reference_table: str, reference_column: str, params: [FieldParameters](Fields.md#fieldparameters) = { })

```python
from Knexpy import Field

_ = Field.foreign_key("<name>", "<ref table>", "<ref column>")
```
